@@ -619,11 +619,13 @@ class ProtMotionCorr(ProtAlignMovies):
         """ Move output from tmp to extra folder. """
         def _moveToExtra(fn):
             """ Move file from movies tmp folder to extra """
-            pwutils.moveFile(self._getCwdPath(movie, fn),
-                             self._getExtraPath(fn))
+            if os.path.exists(self._getCwdPath(movie, fn)):
+                pwutils.moveFile(self._getCwdPath(movie, fn),
+                                 self._getExtraPath(fn))
 
         _moveToExtra(self._getMovieLogFile(movie))
         _moveToExtra(self._getMicFn(movie))
+        _moveToExtra(pwutils.replaceExt(movie.getBaseName(), "star"))
 
         if self._doSaveUnweightedMic():
             _moveToExtra(self._getOutputMicName(movie))
@@ -646,10 +648,14 @@ class ProtMotionCorr(ProtAlignMovies):
 
         if first and outputName == 'outputMovies':
             og = OpticsGroups.fromImages(outputSet)
+            gain = self.getInputMovies().getGain()
+            ogDict = {'rlnMicrographStartFrame': self.alignFrame0.get()}
             if self.isEER:
-                og.updateAll(rlnEERGrouping=self.eerGroup.get(),
-                             rlnEERUpsampling=self.eerSampling.get() + 1)
-            og.updateAll(rlnMicrographStartFrame=self.alignFrame0.get())
+                ogDict.update({'rlnEERGrouping': self.eerGroup.get(),
+                               'rlnEERUpsampling': self.eerSampling.get() + 1})
+            if gain:
+                ogDict['rlnMicrographGainName'] = gain
+            og.updateAll(**ogDict)
             og.toImages(outputSet)
 
         ProtAlignMovies._updateOutputSet(self, outputName, outputSet,
